@@ -1,6 +1,4 @@
 import logging
-import secrets
-import hmac
 from types import SimpleNamespace
 from contextlib import contextmanager
 
@@ -39,18 +37,13 @@ class LogChainer:
 		"""
 		@param named args
 		"""
-		kwargs.setdefault("secret", secrets.token_urlsafe(128))
-		kwargs.setdefault("seed", secrets.token_urlsafe())
 
 		self.verbosity = kwargs.get("verbosity", 0)
 		self.stream = kwargs.get("stream", None)
-		self.secret = kwargs["secret"]
-		self.seed = kwargs["seed"]
 		self.name = kwargs.get("name", None)
 		self.formatterCls = kwargs.get("formatterCls", formatters.Basic)
 
 		self.formatter = self.formatterCls(kwargs)
-		self.extractFunc = kwargs.get("extractSignature", self.formatter.extractSignature)
 
 		# Remaining unused args
 		# if kwargs:
@@ -80,28 +73,25 @@ class LogChainer:
 
 		# TODO, verify the last line somehow
 		for prevLine, line in zip(iLogChain, iLogChain[1:]):
-			aStoredSign = self.extractFunc(line)
-			aComputedSign = self.formatter.sign(prevLine, self.secret)
 
-			isValid = hmac.compare_digest(aStoredSign, aComputedSign)
+			isValid = self.formatter.verify(prevLine, line)
 
 			if not isValid:
-				#print("Inconsistency between lines:\nOK> %s\nKO> %s" % (prevLine, line))
 				return Result(False, prevLine = prevLine, line = line)
 		return Result(True)
 
 
-	def setField(self, **kwargs):
+	def setFields(self, **kwargs):
 		"""
 		Adds contextual data to the log record in the form of key = value
 		Remove a key by setting it to `None`.
 		"""
-		self.formatter.setField(**kwargs)
+		self.formatter.setFields(**kwargs)
 
 	@contextmanager
-	def managedField(self, **kwargs):
+	def managedFields(self, **kwargs):
 		try:
-			previousCtx = self.formatter.setField(**kwargs)
+			previousCtx = self.formatter.setFields(**kwargs)
 			yield
 		finally:
 			self.formatter.context = previousCtx
